Crate runestr_pancjkv

Crate runestr_pancjkv 

rune-based PanCJKV IVD Collection support

PanCJKV IVD Collection is an unregistered IVD collection, that makes use of Unicode Variation Selectors to distinguish CJK ideograph glyphs on a per-region basis.

For example, "\u{6211}" ('我', U+6211) when annotated with PanCJKVRegion::JP, will become "\u{6211}\u{E01E8}", where the variation selector U+E01E8 means Japan region in PanCJKV IVD Collection.

This crate add support for PanCJKV IVD Collection support to rune-based iterators, by allowing unannotated CJK ideograph abstract characters be transformed into annotated form explicitly.

Structs

PanCJKVAnnotateIter
An iterator that annotates rune items with PanCJKV region, usually created with PanCJKVAnnotate::annotate_with_pan_cjkv_region.

Enums

PanCJKVRegion
PanCJKV Region

Traits

PanCJKVAnnotate
Annotate rune iterator items with PanCJKV region.